@@ -4,4 +4,4 @@
 # @Email: 1727949032@qq.com
 # @Software: PyCharm
 
-from py3db.elasticsearch.elastic_search import ElasticSearch
+from py3db.elasticsearch.elastic_search import ElasticSearch as ElasticSearch
